Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(355)

Unified Diff: src/gpu/text/GrAtlasTextContext.h

Issue 1866293003: Decouple contrast boost from fake gamma. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Improve ignorePreBlend API, add storage type to enum Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/text/GrAtlasTextBlob.cpp ('k') | src/gpu/text/GrAtlasTextContext.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/text/GrAtlasTextContext.h
diff --git a/src/gpu/text/GrAtlasTextContext.h b/src/gpu/text/GrAtlasTextContext.h
index a784acb72cdccaa1d29d1f7e7786bc09371c48b4..6d9378304418de7ae360b16afc049dda03992187 100644
--- a/src/gpu/text/GrAtlasTextContext.h
+++ b/src/gpu/text/GrAtlasTextContext.h
@@ -52,12 +52,13 @@ private:
// sets up the descriptor on the blob and returns a detached cache. Client must attach
inline static GrColor ComputeCanonicalColor(const SkPaint&, bool lcd);
- // Determines if we need to use FakeGamma:
- inline static SkPaint::FakeGamma ComputeFakeGamma(GrDrawContext*, const GrPaint&);
+ // Determines if we need to use fake gamma (and contrast boost):
+ inline static uint32_t ComputeScalerContextFlags(GrDrawContext*, const GrPaint&);
static void RegenerateTextBlob(GrAtlasTextBlob* bmp,
GrBatchFontCache*,
const GrShaderCaps&,
- const SkPaint& skPaint, GrColor, SkPaint::FakeGamma,
+ const SkPaint& skPaint, GrColor,
+ uint32_t scalerContextFlags,
const SkMatrix& viewMatrix,
const SkSurfaceProps&,
const SkTextBlob* blob, SkScalar x, SkScalar y,
@@ -67,7 +68,8 @@ private:
static inline GrAtlasTextBlob* CreateDrawTextBlob(GrTextBlobCache*,
GrBatchFontCache*, const GrShaderCaps&,
const GrPaint&,
- const SkPaint&, SkPaint::FakeGamma,
+ const SkPaint&,
+ uint32_t scalerContextFlags,
const SkMatrix& viewMatrix,
const SkSurfaceProps&,
const char text[], size_t byteLength,
@@ -75,7 +77,8 @@ private:
static inline GrAtlasTextBlob* CreateDrawPosTextBlob(GrTextBlobCache*, GrBatchFontCache*,
const GrShaderCaps&,
const GrPaint&,
- const SkPaint&, SkPaint::FakeGamma,
+ const SkPaint&,
+ uint32_t scalerContextFlags,
const SkMatrix& viewMatrix,
const SkSurfaceProps&,
const char text[], size_t byteLength,
@@ -87,7 +90,8 @@ private:
SkAutoTUnref<const GrDistanceFieldAdjustTable> fDistanceAdjustTable;
#ifdef GR_TEST_UTILS
- static const SkPaint::FakeGamma kTextBlobBatchFakeGamma = SkPaint::FakeGamma::On;
+ static const uint32_t kTextBlobBatchScalerContextFlags =
+ SkPaint::kFakeGammaAndBoostContrast_ScalerContextFlags;
DRAW_BATCH_TEST_FRIEND(TextBlobBatch);
#endif
};
« no previous file with comments | « src/gpu/text/GrAtlasTextBlob.cpp ('k') | src/gpu/text/GrAtlasTextContext.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698